pub enum CodeFragment {
Line(String),
Blank,
Raw(String),
Block {
header: String,
body: Vec<CodeFragment>,
close: Option<String>,
},
Indent(Vec<CodeFragment>),
Sequence(Vec<CodeFragment>),
JsDoc(String),
RustDoc(String),
}Expand description
Represents a fragment of generated code.
CodeFragments form an intermediate representation between AST nodes and the final string output, enabling composition and transformation.
Variants
Line(String)
A single line of code (will have newline appended).
Blank
A blank line.
Raw(String)
Raw text without newline.
Block
A block with header, body fragments, and optional closing line.
Indent(Vec<CodeFragment>)
Indent the contained fragments.
Sequence(Vec<CodeFragment>)
A sequence of fragments.
JsDoc(String)
A JSDoc comment.
RustDoc(String)
A Rust doc comment.
Implementations
Sourceimpl CodeFragment
impl CodeFragment
Sourcepub fn block(
header: impl Into<String>,
body: Vec<CodeFragment>,
close: Option<String>,
) -> Self
pub fn block( header: impl Into<String>, body: Vec<CodeFragment>, close: Option<String>, ) -> Self
Create a block fragment.
Sourcepub fn indent(fragments: Vec<CodeFragment>) -> Self
pub fn indent(fragments: Vec<CodeFragment>) -> Self
Create an indented fragment sequence.
Sourcepub fn sequence(fragments: Vec<CodeFragment>) -> Self
pub fn sequence(fragments: Vec<CodeFragment>) -> Self
Create a sequence of fragments.