pub struct BuilderSpec {
pub constructor: Constructor,
pub calls: Vec<MethodCall>,
pub terminal: Terminal,
}Expand description
A declarative specification for a builder pattern.
This represents the intent of building an object via method chaining, independent of any specific language syntax.
Fields
constructor: ConstructorHow to construct the base expression.
calls: Vec<MethodCall>Method calls in order.
terminal: TerminalTerminal operation (await, try, build method).
Implementations
Sourceimpl BuilderSpec
impl BuilderSpec
Sourcepub fn new(type_path: impl Into<String>) -> Self
pub fn new(type_path: impl Into<String>) -> Self
Create a new builder spec with a static ::new() constructor.
Sourcepub fn with_constructor(constructor: Constructor) -> Self
pub fn with_constructor(constructor: Constructor) -> Self
Create a builder spec with a custom constructor.
Sourcepub fn call_arg(self, name: impl Into<String>, value: Value) -> Self
pub fn call_arg(self, name: impl Into<String>, value: Value) -> Self
Add a method call with a single argument.
Sourcepub fn call_args(
self,
name: impl Into<String>,
values: impl IntoIterator<Item = Value>,
) -> Self
pub fn call_args( self, name: impl Into<String>, values: impl IntoIterator<Item = Value>, ) -> Self
Add a method call with multiple arguments.
Sourcepub fn call_if(self, condition: bool, name: impl Into<String>) -> Self
pub fn call_if(self, condition: bool, name: impl Into<String>) -> Self
Conditionally add a method call.
Sourcepub fn call_arg_if(
self,
condition: bool,
name: impl Into<String>,
value: Value,
) -> Self
pub fn call_arg_if( self, condition: bool, name: impl Into<String>, value: Value, ) -> Self
Conditionally add a method call with argument.
Sourcepub fn call_opt(self, name: impl Into<String>, value: Option<Value>) -> Self
pub fn call_opt(self, name: impl Into<String>, value: Option<Value>) -> Self
Add a method call if the value is Some.
Sourcepub fn terminal_method(self, name: impl Into<String>) -> Self
pub fn terminal_method(self, name: impl Into<String>) -> Self
Add a terminal method call.
Sourcepub fn apply_config<I, S>(self, config: I) -> Self
pub fn apply_config<I, S>(self, config: I) -> Self
Apply configuration from an iterator of optional values.
This enables declarative config-to-chain mapping:
spec.apply_config([
("max_connections", config.max.map(Value::uint)),
("timeout", config.timeout.map(Value::duration_secs)),
])Sourcepub fn render(&self, renderer: &dyn Renderer) -> String
pub fn render(&self, renderer: &dyn Renderer) -> String
Render using the given renderer with default options.
Sourcepub fn render_inline(&self, renderer: &dyn Renderer) -> String
pub fn render_inline(&self, renderer: &dyn Renderer) -> String
Render inline using the given renderer.
Sourcepub fn render_with(
&self,
renderer: &dyn Renderer,
opts: &RenderOptions,
) -> String
pub fn render_with( &self, renderer: &dyn Renderer, opts: &RenderOptions, ) -> String
Render with custom options.