pub struct FileEntry {
pub path: String,
pub content: String,
pub category: FileCategory,
pub overwrite: Option<Overwrite>,
}Expand description
An entry in the file registry representing a file to be generated.
Fields
path: StringRelative path from output directory.
content: StringFile content.
category: FileCategoryCategory determining generation behavior.
overwrite: Option<Overwrite>Override default overwrite behavior.
Implementations
Sourceimpl FileEntry
impl FileEntry
Sourcepub fn new(
path: impl Into<String>,
content: impl Into<String>,
category: FileCategory,
) -> Self
pub fn new( path: impl Into<String>, content: impl Into<String>, category: FileCategory, ) -> Self
Create a new file entry with the given category.
Sourcepub fn config(path: impl Into<String>, content: impl Into<String>) -> Self
pub fn config(path: impl Into<String>, content: impl Into<String>) -> Self
Create a config file (always overwritten, generated first).
Sourcepub fn infrastructure(
path: impl Into<String>,
content: impl Into<String>,
) -> Self
pub fn infrastructure( path: impl Into<String>, content: impl Into<String>, ) -> Self
Create an infrastructure file (always overwritten).
Sourcepub fn generated(path: impl Into<String>, content: impl Into<String>) -> Self
pub fn generated(path: impl Into<String>, content: impl Into<String>) -> Self
Create a generated code file (always overwritten).
Sourcepub fn handler(path: impl Into<String>, content: impl Into<String>) -> Self
pub fn handler(path: impl Into<String>, content: impl Into<String>) -> Self
Create a handler stub file (only if missing).
Sourcepub fn with_overwrite(self, overwrite: Overwrite) -> Self
pub fn with_overwrite(self, overwrite: Overwrite) -> Self
Override the default overwrite behavior.
Sourcepub fn write(&self, base: &Path) -> Result<WriteResult>
pub fn write(&self, base: &Path) -> Result<WriteResult>
Write this file to disk.