pub struct SnapshotPlugin { /* private fields */ }Expand description
A plugin that captures pipeline state after each phase.
Use this plugin with the --visualize flag to output intermediate
representations for debugging and understanding the pipeline.
Example
ⓘ
let snapshot_plugin = SnapshotPlugin::new();
let pipeline = Pipeline::new().plugin(snapshot_plugin.clone());
let ctx = pipeline.run(manifest)?;
// Write snapshots to disk
snapshot_plugin.write_to_dir(".bao/debug")?;Implementations
Sourceimpl SnapshotPlugin
impl SnapshotPlugin
Sourcepub fn with_output_dir(output_dir: impl Into<PathBuf>) -> Self
pub fn with_output_dir(output_dir: impl Into<PathBuf>) -> Self
Create a new snapshot plugin that writes to a directory.
Sourcepub fn snapshots(&self) -> Vec<PhaseSnapshot>
pub fn snapshots(&self) -> Vec<PhaseSnapshot>
Get all collected snapshots.