Module schema

Module schema 

Schema traversal and info types.

This module provides types for working with parsed schemas:

Structs

CommandInfo
Info about a command for code generation
CommandTree
A traversable view of the command tree in a schema.
ContextFieldInfo
Info about a context field for code generation
FlatCommand
Flattened command info for easier processing.
PoolConfigInfo
Pool configuration for code generation
SqliteConfigInfo
SQLite-specific configuration for code generation

Functions

collect_context_fields
Collect context fields from the manifest into code generation info.